//
// Copyright (c) 2012 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#ifndef _DICTIONARY_DATA_CONTROL_PROVIDER_H_
#define _DICTIONARY_DATA_CONTROL_PROVIDER_H_

#include <FApp.h>
#include <FBase.h>
#include <FSystem.h>
#include <FUi.h>

/**
 * [DictionaryDataControlProvider] ServiceApp must inherit from ServiceApp class
 * which provides basic features necessary to define an ServiceApp.
 */
class DictionaryDataControlProvider
	: public Tizen::App::ServiceApp
	, public Tizen::App::ISqlDataControlProviderEventListener
	, public Tizen::App::IMapDataControlProviderEventListener
{
public:
	/**
	 * [DictionaryDataControlProvider] ServiceApp must have a factory method that creates an instance of itself.
	 */
	static Tizen::App::ServiceApp* CreateInstance(void);

public:
	DictionaryDataControlProvider(void);
	~DictionaryDataControlProvider(void);

public:
	// Called when the ServiceApp is initializing.
	bool OnAppInitializing(Tizen::App::AppRegistry& appRegistry);

	// Called when the ServiceApp initializing is finished.
	bool OnAppInitialized(void);

	// Called when the ServiceApp is requested to terminate.
	bool OnAppWillTerminate(void);

	// Called when the ServiceApp is terminating.
	bool OnAppTerminating(Tizen::App::AppRegistry& appRegistry, bool forcedTermination = false);

	// Called when the system memory is not sufficient to run the ServiceApp any further.
	void OnLowMemory(void);

	// Called when the battery level changes.
	void OnBatteryLevelChanged(Tizen::System::BatteryLevel batteryLevel);

	// ISqlDataControlProviderEventListener methods
	virtual void OnSqlDataControlSelectRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::Collection::IList* pColumnList, const Tizen::Base::String* pWhere, const Tizen::Base::String* pOrder);

	virtual void OnSqlDataControlInsertRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::Collection::IMap& insertMap);

	virtual void OnSqlDataControlUpdateRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::Collection::IMap& updateMap, const Tizen::Base::String* pWhere);

	virtual void OnSqlDataControlDeleteRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::String* pWhere);

	// IMapDataControlProviderEventListener methods
	virtual void OnMapDataControlGetValueRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::String& key);

	virtual void OnMapDataControlAddValueRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::String& key, const Tizen::Base::String& value);

	virtual void OnMapDataControlSetValueRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::String& key, const Tizen::Base::String& oldValue, const Tizen::Base::String& newValue);

	virtual void OnMapDataControlRemoveValueRequestReceived(RequestId reqId, const Tizen::Base::String& providerId, const Tizen::Base::String& dataId, const Tizen::Base::String& key, const Tizen::Base::String& value);

private:
	Tizen::Base::String __dbPath;
	Tizen::Base::String __regPath;
};

#endif // _DICTIONARY_DATA_CONTROL_PROVIDER_H_
